@@ -182,7 +182,7 @@
 #' @param addMLE if \code{betaPrior=TRUE} was used (non-default),
 #' this logical argument specifies if the "unshrunken" maximum likelihood estimates (MLE)
 #' of log2 fold change should be added as a column to the results table (default is FALSE).
-#' This argument is preserved for backward compatability, as now \code{betaPrior=TRUE}
+#' This argument is preserved for backward compatability, as now \code{betaPrior=FALSE}
 #' by default and the recommended pipeline is
 #' to generate shrunken MAP estimates using \code{\link{lfcShrink}}.
 #' This argument functionality is only implemented for \code{contrast}
@@ -637,7 +637,7 @@ pvalueAdjustment <- function(res, independentFiltering, filter,
     stopifnot(length(filter) == nrow(res))
     filtPadj <- filtered_p(filter=filter, test=res$pvalue,
                            theta=theta, method=pAdjustMethod) 
-    numRej  <- colSums(filtPadj < alpha, na.rm = TRUE)
+    numRej  <- MatrixGenerics::colSums(filtPadj < alpha, na.rm = TRUE)
     # prevent over-aggressive filtering when all genes are null,
     # by requiring the max number of rejections is above a fitted curve.
     # If the max number of rejection is not greater than 10, then don't
@@ -1223,7 +1223,7 @@ contrastAllZeroCharacter <- function(object, contrastFactor,
   cts <- counts(object)
   f <- colData(object)[[contrastFactor]]
   cts.sub <- cts[ , f %in% c(contrastNumLevel, contrastDenomLevel), drop=FALSE ]
-  rowSums( cts.sub == 0 ) == ncol(cts.sub)
+  MatrixGenerics::rowSums( cts.sub == 0 ) == ncol(cts.sub)
 }
 
 contrastAllZeroNumeric <- function(object, contrast) {
